function truth=groundtruth(T,N)
% Bulid the ground truth of state space (three distinct states) 
%
% T:        number of time points
% N:        number of time segments (state remains the same within each segment)
% truth:    ground truth of state space of size T x 1
%
%
% The mathematical detail is given in
% Huang, S.-G., Chung, M.K., Carroll, I.C., Goldsmith, H.H. 2019 Dynamic 
% functional connectivity using heat kernel. IEEE Data Science Workshop (DSW)
% http://pages.stat.wisc.edu/~mchung/papers/huang.2019.DSW.pdf
%
%
% (C) 2019 Shih-Gu Huang shihgu@gmail.com
%          Moo K. Chung  mkchung@wisc.edu
%          Universtiy of Wisconsin-Madison
%
% Update history:
%     May  7, 2019 created by Huang
%     May 24, 2019 edited by Chung
%
% N state labels for the N time segments
state=ones(N,1);

% Make sure there are 3 distinct states. Otherwise, the truth will not
% match the estimation from k-means clustering with 3 partions.
while length(unique(state))~=3      
    state(1)=randi(3,[1 1]);
    for i=2:N
        
        %  Assume there is no transition between States 1 and 3 
        if state(i-1)==1
            tmp=[1 2];
            state(i)=tmp(randi(2,[1 1]));
        elseif state(i-1)==2
            tmp=[1 2 3];
            state(i)=tmp(randi(3,[1 1]));
        else
            tmp=[2 3];
            state(i)=tmp(randi(2,[1 1]));
        end
        
    end
end
 
%% T state labels at the T time points
truth=zeros(T,1);
num=floor(T/N); % num of time points in each segment

% 1,...,num time points are in the same state,
% num+1,...,2*num time points are in the same state, and so on.
tmp=kron( state,  ones(num,1)  );
truth( 1:num*N )=tmp;
truth( num*N+1:end )=tmp(end);


