function [state,centroid]=kmeans_sort(data,K,rep)
% k-means clustering with sorted ouput.
%
% data:     input data of size N x T
% K:        number of clusters
% rep:      number of replicates in k-means clutering
% state:    estimated state space of size N x 1
% centroid: K cluster centroids, i.e., average correlations
%
% The mathematical detail is given in
% Huang, S.-G., Chung, M.K., Carroll, I.C., Goldsmith, H.H. 2019 Dynamic 
% functional connectivity using heat kernel. IEEE Data Science Workshop (DSW)
% http://pages.stat.wisc.edu/~mchung/papers/huang.2019.DSW.pdf
%
%
% (C) 2019 Shih-Gu Huang shihgu@gmail.com
%          Moo K. Chung  mkchung@wisc.edu
%          Universtiy of Wisconsin-Madison
%
% Update history:
%     May  7, 2019 created by Huang
%     May 24, 2019 edited by Chung

%% k-means clustering of data into K partitions
[state,centroid] = kmeans(data,K,'Replicates',rep);


%% Swap states by sorting centroids in decending order
[~,ind1]=sort(mean(centroid,2),'descend');
centroid=centroid(ind1,:);

[~,ind2]=sort(ind1,'ascend');
state=ind2(state);

